@@ -76,14 +76,7 @@ class UserSaver(SaveUtilsMixin, object):
             "fetch_time": fetch_time,
             "raw": raw_json,
             "nsid": user["nsid"],
-            "is_pro": (int(user["ispro"]) == 1),
-            "iconserver": user["iconserver"],
-            "iconfarm": user["iconfarm"],
             "username": user["username"]["_content"],
-            "realname": user["realname"]["_content"],
-            "description": user["description"]["_content"],
-            "photos_url": user["photosurl"]["_content"],
-            "profile_url": user["profileurl"]["_content"],
             "photos_count": int(user["photos"]["count"]["_content"]),
             "photos_first_date": self._unixtime_to_datetime(
                 user["photos"]["firstdate"]["_content"]
@@ -93,6 +86,24 @@ class UserSaver(SaveUtilsMixin, object):
             ),
         }
 
+        # Things we won't have in our dummy data if the user was deleted:
+        if "iconserver" in user:
+            defaults["iconserver"] = user["iconserver"]
+        if "iconfarm" in user:
+            defaults["iconfarm"] = user["iconfarm"]
+        if "ispro" in user:
+            defaults["is_pro"] = (int(user["ispro"]) == 1)
+        if "description" in user:
+            defaults["description"] = user["description"]["_content"]
+        if "photosurl" in user:
+            defaults["photos_url"] = user["photosurl"]["_content"]
+        if "profileurl" in user:
+            defaults["profile_url"] = user["profileurl"]["_content"]
+
+        # Surprisingly, not always present:
+        if "realname" in user:
+            defaults["realname"] = user["realname"]["_content"]
+
         # 'location' and 'timezone' were missing for at least one user fetched:
         if "location" in user:
             defaults["location"] = user["location"]["_content"]
@@ -242,8 +253,10 @@ class PhotoSaver(SaveUtilsMixin, object):
             if size["label"] in sizes:
                 # eg, 'X-Large 3K' becomes 'x_large_3k':
                 name = size["label"].lower().replace(" ", "_").replace("-", "_")
-                defaults[name + "_width"] = int(size["width"])
-                defaults[name + "_height"] = int(size["height"])
+                if size["width"] is not None:
+                    defaults[name + "_width"] = int(size["width"])
+                if size["height"] is not None:
+                    defaults[name + "_height"] = int(size["height"])
 
         try:
             for e in photo["exif"]["exif"]:
