@@ -844,18 +844,18 @@ class User(TimeStampedModelMixin, DiffModelMixin, models.Model):
         null=False, blank=False, default=False, verbose_name="Is Pro?"
     )
     iconserver = models.PositiveIntegerField(null=False, blank=False, default=0)
-    iconfarm = models.PositiveIntegerField(null=False, blank=False)
+    iconfarm = models.PositiveIntegerField(null=False, blank=False, default=0)
 
     username = models.CharField(null=False, blank=False, unique=True, max_length=50)
-    realname = models.CharField(null=False, blank=False, max_length=255)
+    realname = models.CharField(null=False, blank=True, max_length=255)
     location = models.CharField(null=False, blank=True, max_length=255)
     description = models.TextField(null=False, blank=True, help_text="May contain HTML")
 
     photos_url = models.URLField(
-        null=False, blank=False, max_length=255, verbose_name="Photos URL at Flickr"
+        null=False, blank=True, max_length=255, verbose_name="Photos URL at Flickr"
     )
     profile_url = models.URLField(
-        null=False, blank=False, max_length=255, verbose_name="Avatar URL on Flickr"
+        null=False, blank=True, max_length=255, verbose_name="Avatar URL on Flickr"
     )
 
     photos_count = models.PositiveIntegerField(null=False, blank=False, default=0)
@@ -901,17 +901,17 @@ class User(TimeStampedModelMixin, DiffModelMixin, models.Model):
     objects_with_accounts = managers.WithAccountsManager()
 
     def __str__(self):
-        return self.realname
+        return self.realname if self.realname else self.username
 
     class Meta:
-        ordering = ["realname"]
+        ordering = ["realname", "username"]
 
     def get_absolute_url(self):
         return reverse("flickr:user_detail", kwargs={"nsid": self.nsid})
 
     @property
     def name(self):
-        return self.realname
+        return self.realname if self.realname else self.username
 
     @property
     def permalink(self):
